# Funciones para resolver sistemas de ecuaciones
## Este proyecto contiene una librería que implementa ciertos métodos para resolver sistemas de ecuaciones lineales

## Métodos incluidos
- <strong>Método de elimnación de Gauss</strong>
- <strong>Método de Gauss-Jordan</strong>
- <strong>Método de Cramer</strong>
- <strong>Método de Descomposición LU</strong>
- <strong>Método de Jacobi</strong>
- <strong>Método de Gauss-Seidel</strong>
- <strong>Método de Bisección</strong>
- <strong>Método de Gauss-Jordan</strong>

## Autor: MD23005

---

# Instalación
## pip install MD23005UNO